# Release information about submodal

version = "1.5"

description = "Cross Browser DHTML Modal Dialogs For Web Apps"
long_description = """\
The subModal works by placing a semi-transparent div over the browser, blocking \
access to the content below while still providing visibility. This maintains \
state and doesn't make someone feel disoriented or lost by moving them \
completely to another page. Their frame of reference is kept while allowing them \
to perform a new task (usually closely associated with the content below). \
\
This version was based on the enhanced subModal provided by Todd Huss.\
"""
author = "Jorge Godoy (packager)"
email = "jgodoy@gmail.com"

url = "http://gabrito.com/post/enhancements-to-submodal"
license = "Free for any use - See included files"
